# coding: utf-8

"""
    Aron API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


try:
    from inspect import getfullargspec
except ImportError:
    from inspect import getargspec as getfullargspec
import pprint
import re  # noqa: F401
import six

from openapi_client.configuration import Configuration


class OrmPipelineSpec(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'archived_dt': 'datetime',
        'created_dt': 'datetime',
        'edges': 'OrmPipelineSpecEdges',
        'id': 'int',
        'parameter_spec': 'dict[str, object]',
        'pipeline_id': 'int',
        'publish_message': 'str',
        'published': 'bool',
        'published_dt': 'datetime',
        'revision': 'int',
        'spec': 'dict[str, object]',
        'step_dependencies': 'dict[str, object]',
        'updated_dt': 'datetime'
    }

    attribute_map = {
        'archived_dt': 'archived_dt',
        'created_dt': 'created_dt',
        'edges': 'edges',
        'id': 'id',
        'parameter_spec': 'parameter_spec',
        'pipeline_id': 'pipeline_id',
        'publish_message': 'publish_message',
        'published': 'published',
        'published_dt': 'published_dt',
        'revision': 'revision',
        'spec': 'spec',
        'step_dependencies': 'step_dependencies',
        'updated_dt': 'updated_dt'
    }

    def __init__(self, archived_dt=None, created_dt=None, edges=None, id=None, parameter_spec=None, pipeline_id=None, publish_message=None, published=None, published_dt=None, revision=None, spec=None, step_dependencies=None, updated_dt=None, local_vars_configuration=None):  # noqa: E501
        """OrmPipelineSpec - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration.get_default_copy()
        self.local_vars_configuration = local_vars_configuration

        self._archived_dt = None
        self._created_dt = None
        self._edges = None
        self._id = None
        self._parameter_spec = None
        self._pipeline_id = None
        self._publish_message = None
        self._published = None
        self._published_dt = None
        self._revision = None
        self._spec = None
        self._step_dependencies = None
        self._updated_dt = None
        self.discriminator = None

        self.archived_dt = archived_dt
        if created_dt is not None:
            self.created_dt = created_dt
        if edges is not None:
            self.edges = edges
        if id is not None:
            self.id = id
        if parameter_spec is not None:
            self.parameter_spec = parameter_spec
        if pipeline_id is not None:
            self.pipeline_id = pipeline_id
        self.publish_message = publish_message
        if published is not None:
            self.published = published
        self.published_dt = published_dt
        if revision is not None:
            self.revision = revision
        if spec is not None:
            self.spec = spec
        if step_dependencies is not None:
            self.step_dependencies = step_dependencies
        if updated_dt is not None:
            self.updated_dt = updated_dt

    @property
    def archived_dt(self):
        """Gets the archived_dt of this OrmPipelineSpec.  # noqa: E501


        :return: The archived_dt of this OrmPipelineSpec.  # noqa: E501
        :rtype: datetime
        """
        return self._archived_dt

    @archived_dt.setter
    def archived_dt(self, archived_dt):
        """Sets the archived_dt of this OrmPipelineSpec.


        :param archived_dt: The archived_dt of this OrmPipelineSpec.  # noqa: E501
        :type archived_dt: datetime
        """

        self._archived_dt = archived_dt

    @property
    def created_dt(self):
        """Gets the created_dt of this OrmPipelineSpec.  # noqa: E501


        :return: The created_dt of this OrmPipelineSpec.  # noqa: E501
        :rtype: datetime
        """
        return self._created_dt

    @created_dt.setter
    def created_dt(self, created_dt):
        """Sets the created_dt of this OrmPipelineSpec.


        :param created_dt: The created_dt of this OrmPipelineSpec.  # noqa: E501
        :type created_dt: datetime
        """

        self._created_dt = created_dt

    @property
    def edges(self):
        """Gets the edges of this OrmPipelineSpec.  # noqa: E501


        :return: The edges of this OrmPipelineSpec.  # noqa: E501
        :rtype: OrmPipelineSpecEdges
        """
        return self._edges

    @edges.setter
    def edges(self, edges):
        """Sets the edges of this OrmPipelineSpec.


        :param edges: The edges of this OrmPipelineSpec.  # noqa: E501
        :type edges: OrmPipelineSpecEdges
        """

        self._edges = edges

    @property
    def id(self):
        """Gets the id of this OrmPipelineSpec.  # noqa: E501


        :return: The id of this OrmPipelineSpec.  # noqa: E501
        :rtype: int
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this OrmPipelineSpec.


        :param id: The id of this OrmPipelineSpec.  # noqa: E501
        :type id: int
        """

        self._id = id

    @property
    def parameter_spec(self):
        """Gets the parameter_spec of this OrmPipelineSpec.  # noqa: E501


        :return: The parameter_spec of this OrmPipelineSpec.  # noqa: E501
        :rtype: dict[str, object]
        """
        return self._parameter_spec

    @parameter_spec.setter
    def parameter_spec(self, parameter_spec):
        """Sets the parameter_spec of this OrmPipelineSpec.


        :param parameter_spec: The parameter_spec of this OrmPipelineSpec.  # noqa: E501
        :type parameter_spec: dict[str, object]
        """

        self._parameter_spec = parameter_spec

    @property
    def pipeline_id(self):
        """Gets the pipeline_id of this OrmPipelineSpec.  # noqa: E501


        :return: The pipeline_id of this OrmPipelineSpec.  # noqa: E501
        :rtype: int
        """
        return self._pipeline_id

    @pipeline_id.setter
    def pipeline_id(self, pipeline_id):
        """Sets the pipeline_id of this OrmPipelineSpec.


        :param pipeline_id: The pipeline_id of this OrmPipelineSpec.  # noqa: E501
        :type pipeline_id: int
        """

        self._pipeline_id = pipeline_id

    @property
    def publish_message(self):
        """Gets the publish_message of this OrmPipelineSpec.  # noqa: E501


        :return: The publish_message of this OrmPipelineSpec.  # noqa: E501
        :rtype: str
        """
        return self._publish_message

    @publish_message.setter
    def publish_message(self, publish_message):
        """Sets the publish_message of this OrmPipelineSpec.


        :param publish_message: The publish_message of this OrmPipelineSpec.  # noqa: E501
        :type publish_message: str
        """

        self._publish_message = publish_message

    @property
    def published(self):
        """Gets the published of this OrmPipelineSpec.  # noqa: E501


        :return: The published of this OrmPipelineSpec.  # noqa: E501
        :rtype: bool
        """
        return self._published

    @published.setter
    def published(self, published):
        """Sets the published of this OrmPipelineSpec.


        :param published: The published of this OrmPipelineSpec.  # noqa: E501
        :type published: bool
        """

        self._published = published

    @property
    def published_dt(self):
        """Gets the published_dt of this OrmPipelineSpec.  # noqa: E501


        :return: The published_dt of this OrmPipelineSpec.  # noqa: E501
        :rtype: datetime
        """
        return self._published_dt

    @published_dt.setter
    def published_dt(self, published_dt):
        """Sets the published_dt of this OrmPipelineSpec.


        :param published_dt: The published_dt of this OrmPipelineSpec.  # noqa: E501
        :type published_dt: datetime
        """

        self._published_dt = published_dt

    @property
    def revision(self):
        """Gets the revision of this OrmPipelineSpec.  # noqa: E501


        :return: The revision of this OrmPipelineSpec.  # noqa: E501
        :rtype: int
        """
        return self._revision

    @revision.setter
    def revision(self, revision):
        """Sets the revision of this OrmPipelineSpec.


        :param revision: The revision of this OrmPipelineSpec.  # noqa: E501
        :type revision: int
        """

        self._revision = revision

    @property
    def spec(self):
        """Gets the spec of this OrmPipelineSpec.  # noqa: E501


        :return: The spec of this OrmPipelineSpec.  # noqa: E501
        :rtype: dict[str, object]
        """
        return self._spec

    @spec.setter
    def spec(self, spec):
        """Sets the spec of this OrmPipelineSpec.


        :param spec: The spec of this OrmPipelineSpec.  # noqa: E501
        :type spec: dict[str, object]
        """

        self._spec = spec

    @property
    def step_dependencies(self):
        """Gets the step_dependencies of this OrmPipelineSpec.  # noqa: E501


        :return: The step_dependencies of this OrmPipelineSpec.  # noqa: E501
        :rtype: dict[str, object]
        """
        return self._step_dependencies

    @step_dependencies.setter
    def step_dependencies(self, step_dependencies):
        """Sets the step_dependencies of this OrmPipelineSpec.


        :param step_dependencies: The step_dependencies of this OrmPipelineSpec.  # noqa: E501
        :type step_dependencies: dict[str, object]
        """

        self._step_dependencies = step_dependencies

    @property
    def updated_dt(self):
        """Gets the updated_dt of this OrmPipelineSpec.  # noqa: E501


        :return: The updated_dt of this OrmPipelineSpec.  # noqa: E501
        :rtype: datetime
        """
        return self._updated_dt

    @updated_dt.setter
    def updated_dt(self, updated_dt):
        """Sets the updated_dt of this OrmPipelineSpec.


        :param updated_dt: The updated_dt of this OrmPipelineSpec.  # noqa: E501
        :type updated_dt: datetime
        """

        self._updated_dt = updated_dt

    def to_dict(self, serialize=False):
        """Returns the model properties as a dict"""
        result = {}

        def convert(x):
            if hasattr(x, "to_dict"):
                args = getfullargspec(x.to_dict).args
                if len(args) == 1:
                    return x.to_dict()
                else:
                    return x.to_dict(serialize)
            else:
                return x

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            attr = self.attribute_map.get(attr, attr) if serialize else attr
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: convert(x),
                    value
                ))
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], convert(item[1])),
                    value.items()
                ))
            else:
                result[attr] = convert(value)

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, OrmPipelineSpec):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, OrmPipelineSpec):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Aron API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


try:
    from inspect import getfullargspec
except ImportError:
    from inspect import getargspec as getfullargspec
import pprint
import re  # noqa: F401
import six

from openapi_client.configuration import Configuration


class SamlContactPerson(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'company': 'str',
        'contact_type': 'str',
        'email_addresses': 'list[str]',
        'given_name': 'str',
        'sur_name': 'str',
        'telephone_numbers': 'list[str]'
    }

    attribute_map = {
        'company': 'Company',
        'contact_type': 'ContactType',
        'email_addresses': 'EmailAddresses',
        'given_name': 'GivenName',
        'sur_name': 'SurName',
        'telephone_numbers': 'TelephoneNumbers'
    }

    def __init__(self, company=None, contact_type=None, email_addresses=None, given_name=None, sur_name=None, telephone_numbers=None, local_vars_configuration=None):  # noqa: E501
        """SamlContactPerson - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration.get_default_copy()
        self.local_vars_configuration = local_vars_configuration

        self._company = None
        self._contact_type = None
        self._email_addresses = None
        self._given_name = None
        self._sur_name = None
        self._telephone_numbers = None
        self.discriminator = None

        if company is not None:
            self.company = company
        if contact_type is not None:
            self.contact_type = contact_type
        if email_addresses is not None:
            self.email_addresses = email_addresses
        if given_name is not None:
            self.given_name = given_name
        if sur_name is not None:
            self.sur_name = sur_name
        if telephone_numbers is not None:
            self.telephone_numbers = telephone_numbers

    @property
    def company(self):
        """Gets the company of this SamlContactPerson.  # noqa: E501


        :return: The company of this SamlContactPerson.  # noqa: E501
        :rtype: str
        """
        return self._company

    @company.setter
    def company(self, company):
        """Sets the company of this SamlContactPerson.


        :param company: The company of this SamlContactPerson.  # noqa: E501
        :type company: str
        """

        self._company = company

    @property
    def contact_type(self):
        """Gets the contact_type of this SamlContactPerson.  # noqa: E501


        :return: The contact_type of this SamlContactPerson.  # noqa: E501
        :rtype: str
        """
        return self._contact_type

    @contact_type.setter
    def contact_type(self, contact_type):
        """Sets the contact_type of this SamlContactPerson.


        :param contact_type: The contact_type of this SamlContactPerson.  # noqa: E501
        :type contact_type: str
        """

        self._contact_type = contact_type

    @property
    def email_addresses(self):
        """Gets the email_addresses of this SamlContactPerson.  # noqa: E501


        :return: The email_addresses of this SamlContactPerson.  # noqa: E501
        :rtype: list[str]
        """
        return self._email_addresses

    @email_addresses.setter
    def email_addresses(self, email_addresses):
        """Sets the email_addresses of this SamlContactPerson.


        :param email_addresses: The email_addresses of this SamlContactPerson.  # noqa: E501
        :type email_addresses: list[str]
        """

        self._email_addresses = email_addresses

    @property
    def given_name(self):
        """Gets the given_name of this SamlContactPerson.  # noqa: E501


        :return: The given_name of this SamlContactPerson.  # noqa: E501
        :rtype: str
        """
        return self._given_name

    @given_name.setter
    def given_name(self, given_name):
        """Sets the given_name of this SamlContactPerson.


        :param given_name: The given_name of this SamlContactPerson.  # noqa: E501
        :type given_name: str
        """

        self._given_name = given_name

    @property
    def sur_name(self):
        """Gets the sur_name of this SamlContactPerson.  # noqa: E501


        :return: The sur_name of this SamlContactPerson.  # noqa: E501
        :rtype: str
        """
        return self._sur_name

    @sur_name.setter
    def sur_name(self, sur_name):
        """Sets the sur_name of this SamlContactPerson.


        :param sur_name: The sur_name of this SamlContactPerson.  # noqa: E501
        :type sur_name: str
        """

        self._sur_name = sur_name

    @property
    def telephone_numbers(self):
        """Gets the telephone_numbers of this SamlContactPerson.  # noqa: E501


        :return: The telephone_numbers of this SamlContactPerson.  # noqa: E501
        :rtype: list[str]
        """
        return self._telephone_numbers

    @telephone_numbers.setter
    def telephone_numbers(self, telephone_numbers):
        """Sets the telephone_numbers of this SamlContactPerson.


        :param telephone_numbers: The telephone_numbers of this SamlContactPerson.  # noqa: E501
        :type telephone_numbers: list[str]
        """

        self._telephone_numbers = telephone_numbers

    def to_dict(self, serialize=False):
        """Returns the model properties as a dict"""
        result = {}

        def convert(x):
            if hasattr(x, "to_dict"):
                args = getfullargspec(x.to_dict).args
                if len(args) == 1:
                    return x.to_dict()
                else:
                    return x.to_dict(serialize)
            else:
                return x

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            attr = self.attribute_map.get(attr, attr) if serialize else attr
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: convert(x),
                    value
                ))
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], convert(item[1])),
                    value.items()
                ))
            else:
                result[attr] = convert(value)

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, SamlContactPerson):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, SamlContactPerson):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Aron API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


try:
    from inspect import getfullargspec
except ImportError:
    from inspect import getargspec as getfullargspec
import pprint
import re  # noqa: F401
import six

from openapi_client.configuration import Configuration


class OrmPipelineExecution(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'arguments': 'dict[str, object]',
        'created_dt': 'datetime',
        'debug_enabled': 'bool',
        'edges': 'OrmPipelineExecutionEdges',
        'end_dt': 'datetime',
        'id': 'int',
        'immutable_slug': 'str',
        'number': 'int',
        'output_variables': 'dict[str, object]',
        'pipeline_id': 'int',
        'pipeline_spec_id': 'int',
        'reason': 'str',
        'source_trigger_id': 'int',
        'status': 'str',
        'triggered_user_id': 'int',
        'updated_dt': 'datetime'
    }

    attribute_map = {
        'arguments': 'arguments',
        'created_dt': 'created_dt',
        'debug_enabled': 'debug_enabled',
        'edges': 'edges',
        'end_dt': 'end_dt',
        'id': 'id',
        'immutable_slug': 'immutable_slug',
        'number': 'number',
        'output_variables': 'output_variables',
        'pipeline_id': 'pipeline_id',
        'pipeline_spec_id': 'pipeline_spec_id',
        'reason': 'reason',
        'source_trigger_id': 'source_trigger_id',
        'status': 'status',
        'triggered_user_id': 'triggered_user_id',
        'updated_dt': 'updated_dt'
    }

    def __init__(self, arguments=None, created_dt=None, debug_enabled=None, edges=None, end_dt=None, id=None, immutable_slug=None, number=None, output_variables=None, pipeline_id=None, pipeline_spec_id=None, reason=None, source_trigger_id=None, status=None, triggered_user_id=None, updated_dt=None, local_vars_configuration=None):  # noqa: E501
        """OrmPipelineExecution - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration.get_default_copy()
        self.local_vars_configuration = local_vars_configuration

        self._arguments = None
        self._created_dt = None
        self._debug_enabled = None
        self._edges = None
        self._end_dt = None
        self._id = None
        self._immutable_slug = None
        self._number = None
        self._output_variables = None
        self._pipeline_id = None
        self._pipeline_spec_id = None
        self._reason = None
        self._source_trigger_id = None
        self._status = None
        self._triggered_user_id = None
        self._updated_dt = None
        self.discriminator = None

        if arguments is not None:
            self.arguments = arguments
        if created_dt is not None:
            self.created_dt = created_dt
        if debug_enabled is not None:
            self.debug_enabled = debug_enabled
        if edges is not None:
            self.edges = edges
        self.end_dt = end_dt
        if id is not None:
            self.id = id
        if immutable_slug is not None:
            self.immutable_slug = immutable_slug
        if number is not None:
            self.number = number
        if output_variables is not None:
            self.output_variables = output_variables
        if pipeline_id is not None:
            self.pipeline_id = pipeline_id
        if pipeline_spec_id is not None:
            self.pipeline_spec_id = pipeline_spec_id
        if reason is not None:
            self.reason = reason
        self.source_trigger_id = source_trigger_id
        if status is not None:
            self.status = status
        self.triggered_user_id = triggered_user_id
        if updated_dt is not None:
            self.updated_dt = updated_dt

    @property
    def arguments(self):
        """Gets the arguments of this OrmPipelineExecution.  # noqa: E501


        :return: The arguments of this OrmPipelineExecution.  # noqa: E501
        :rtype: dict[str, object]
        """
        return self._arguments

    @arguments.setter
    def arguments(self, arguments):
        """Sets the arguments of this OrmPipelineExecution.


        :param arguments: The arguments of this OrmPipelineExecution.  # noqa: E501
        :type arguments: dict[str, object]
        """

        self._arguments = arguments

    @property
    def created_dt(self):
        """Gets the created_dt of this OrmPipelineExecution.  # noqa: E501


        :return: The created_dt of this OrmPipelineExecution.  # noqa: E501
        :rtype: datetime
        """
        return self._created_dt

    @created_dt.setter
    def created_dt(self, created_dt):
        """Sets the created_dt of this OrmPipelineExecution.


        :param created_dt: The created_dt of this OrmPipelineExecution.  # noqa: E501
        :type created_dt: datetime
        """

        self._created_dt = created_dt

    @property
    def debug_enabled(self):
        """Gets the debug_enabled of this OrmPipelineExecution.  # noqa: E501


        :return: The debug_enabled of this OrmPipelineExecution.  # noqa: E501
        :rtype: bool
        """
        return self._debug_enabled

    @debug_enabled.setter
    def debug_enabled(self, debug_enabled):
        """Sets the debug_enabled of this OrmPipelineExecution.


        :param debug_enabled: The debug_enabled of this OrmPipelineExecution.  # noqa: E501
        :type debug_enabled: bool
        """

        self._debug_enabled = debug_enabled

    @property
    def edges(self):
        """Gets the edges of this OrmPipelineExecution.  # noqa: E501


        :return: The edges of this OrmPipelineExecution.  # noqa: E501
        :rtype: OrmPipelineExecutionEdges
        """
        return self._edges

    @edges.setter
    def edges(self, edges):
        """Sets the edges of this OrmPipelineExecution.


        :param edges: The edges of this OrmPipelineExecution.  # noqa: E501
        :type edges: OrmPipelineExecutionEdges
        """

        self._edges = edges

    @property
    def end_dt(self):
        """Gets the end_dt of this OrmPipelineExecution.  # noqa: E501


        :return: The end_dt of this OrmPipelineExecution.  # noqa: E501
        :rtype: datetime
        """
        return self._end_dt

    @end_dt.setter
    def end_dt(self, end_dt):
        """Sets the end_dt of this OrmPipelineExecution.


        :param end_dt: The end_dt of this OrmPipelineExecution.  # noqa: E501
        :type end_dt: datetime
        """

        self._end_dt = end_dt

    @property
    def id(self):
        """Gets the id of this OrmPipelineExecution.  # noqa: E501


        :return: The id of this OrmPipelineExecution.  # noqa: E501
        :rtype: int
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this OrmPipelineExecution.


        :param id: The id of this OrmPipelineExecution.  # noqa: E501
        :type id: int
        """

        self._id = id

    @property
    def immutable_slug(self):
        """Gets the immutable_slug of this OrmPipelineExecution.  # noqa: E501


        :return: The immutable_slug of this OrmPipelineExecution.  # noqa: E501
        :rtype: str
        """
        return self._immutable_slug

    @immutable_slug.setter
    def immutable_slug(self, immutable_slug):
        """Sets the immutable_slug of this OrmPipelineExecution.


        :param immutable_slug: The immutable_slug of this OrmPipelineExecution.  # noqa: E501
        :type immutable_slug: str
        """

        self._immutable_slug = immutable_slug

    @property
    def number(self):
        """Gets the number of this OrmPipelineExecution.  # noqa: E501


        :return: The number of this OrmPipelineExecution.  # noqa: E501
        :rtype: int
        """
        return self._number

    @number.setter
    def number(self, number):
        """Sets the number of this OrmPipelineExecution.


        :param number: The number of this OrmPipelineExecution.  # noqa: E501
        :type number: int
        """

        self._number = number

    @property
    def output_variables(self):
        """Gets the output_variables of this OrmPipelineExecution.  # noqa: E501


        :return: The output_variables of this OrmPipelineExecution.  # noqa: E501
        :rtype: dict[str, object]
        """
        return self._output_variables

    @output_variables.setter
    def output_variables(self, output_variables):
        """Sets the output_variables of this OrmPipelineExecution.


        :param output_variables: The output_variables of this OrmPipelineExecution.  # noqa: E501
        :type output_variables: dict[str, object]
        """

        self._output_variables = output_variables

    @property
    def pipeline_id(self):
        """Gets the pipeline_id of this OrmPipelineExecution.  # noqa: E501


        :return: The pipeline_id of this OrmPipelineExecution.  # noqa: E501
        :rtype: int
        """
        return self._pipeline_id

    @pipeline_id.setter
    def pipeline_id(self, pipeline_id):
        """Sets the pipeline_id of this OrmPipelineExecution.


        :param pipeline_id: The pipeline_id of this OrmPipelineExecution.  # noqa: E501
        :type pipeline_id: int
        """

        self._pipeline_id = pipeline_id

    @property
    def pipeline_spec_id(self):
        """Gets the pipeline_spec_id of this OrmPipelineExecution.  # noqa: E501


        :return: The pipeline_spec_id of this OrmPipelineExecution.  # noqa: E501
        :rtype: int
        """
        return self._pipeline_spec_id

    @pipeline_spec_id.setter
    def pipeline_spec_id(self, pipeline_spec_id):
        """Sets the pipeline_spec_id of this OrmPipelineExecution.


        :param pipeline_spec_id: The pipeline_spec_id of this OrmPipelineExecution.  # noqa: E501
        :type pipeline_spec_id: int
        """

        self._pipeline_spec_id = pipeline_spec_id

    @property
    def reason(self):
        """Gets the reason of this OrmPipelineExecution.  # noqa: E501


        :return: The reason of this OrmPipelineExecution.  # noqa: E501
        :rtype: str
        """
        return self._reason

    @reason.setter
    def reason(self, reason):
        """Sets the reason of this OrmPipelineExecution.


        :param reason: The reason of this OrmPipelineExecution.  # noqa: E501
        :type reason: str
        """

        self._reason = reason

    @property
    def source_trigger_id(self):
        """Gets the source_trigger_id of this OrmPipelineExecution.  # noqa: E501


        :return: The source_trigger_id of this OrmPipelineExecution.  # noqa: E501
        :rtype: int
        """
        return self._source_trigger_id

    @source_trigger_id.setter
    def source_trigger_id(self, source_trigger_id):
        """Sets the source_trigger_id of this OrmPipelineExecution.


        :param source_trigger_id: The source_trigger_id of this OrmPipelineExecution.  # noqa: E501
        :type source_trigger_id: int
        """

        self._source_trigger_id = source_trigger_id

    @property
    def status(self):
        """Gets the status of this OrmPipelineExecution.  # noqa: E501


        :return: The status of this OrmPipelineExecution.  # noqa: E501
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this OrmPipelineExecution.


        :param status: The status of this OrmPipelineExecution.  # noqa: E501
        :type status: str
        """

        self._status = status

    @property
    def triggered_user_id(self):
        """Gets the triggered_user_id of this OrmPipelineExecution.  # noqa: E501


        :return: The triggered_user_id of this OrmPipelineExecution.  # noqa: E501
        :rtype: int
        """
        return self._triggered_user_id

    @triggered_user_id.setter
    def triggered_user_id(self, triggered_user_id):
        """Sets the triggered_user_id of this OrmPipelineExecution.


        :param triggered_user_id: The triggered_user_id of this OrmPipelineExecution.  # noqa: E501
        :type triggered_user_id: int
        """

        self._triggered_user_id = triggered_user_id

    @property
    def updated_dt(self):
        """Gets the updated_dt of this OrmPipelineExecution.  # noqa: E501


        :return: The updated_dt of this OrmPipelineExecution.  # noqa: E501
        :rtype: datetime
        """
        return self._updated_dt

    @updated_dt.setter
    def updated_dt(self, updated_dt):
        """Sets the updated_dt of this OrmPipelineExecution.


        :param updated_dt: The updated_dt of this OrmPipelineExecution.  # noqa: E501
        :type updated_dt: datetime
        """

        self._updated_dt = updated_dt

    def to_dict(self, serialize=False):
        """Returns the model properties as a dict"""
        result = {}

        def convert(x):
            if hasattr(x, "to_dict"):
                args = getfullargspec(x.to_dict).args
                if len(args) == 1:
                    return x.to_dict()
                else:
                    return x.to_dict(serialize)
            else:
                return x

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            attr = self.attribute_map.get(attr, attr) if serialize else attr
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: convert(x),
                    value
                ))
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], convert(item[1])),
                    value.items()
                ))
            else:
                result[attr] = convert(value)

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, OrmPipelineExecution):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, OrmPipelineExecution):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Aron API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


try:
    from inspect import getfullargspec
except ImportError:
    from inspect import getargspec as getfullargspec
import pprint
import re  # noqa: F401
import six

from openapi_client.configuration import Configuration


class OrmLLMKnowledgeEdges(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'cluster': 'OrmKernelCluster',
        'created_by': 'OrmUser',
        'embedding_model': 'OrmLLMModelConnection',
        'llm_documents': 'list[OrmLLMDocument]',
        'llm_knowledge_jobs': 'list[OrmLLMKnowledgeJob]',
        'llm_knowledge_llm_user_group': 'list[OrmLLMKnowledgeLLMUserGroup]',
        'organization': 'OrmOrganization',
        'resource_spec_preset': 'OrmKernelResourceSpec',
        'vectordb_connection': 'OrmLLMVectorDBConnection'
    }

    attribute_map = {
        'cluster': 'cluster',
        'created_by': 'created_by',
        'embedding_model': 'embedding_model',
        'llm_documents': 'llm_documents',
        'llm_knowledge_jobs': 'llm_knowledge_jobs',
        'llm_knowledge_llm_user_group': 'llm_knowledge_llm_user_group',
        'organization': 'organization',
        'resource_spec_preset': 'resource_spec_preset',
        'vectordb_connection': 'vectordb_connection'
    }

    def __init__(self, cluster=None, created_by=None, embedding_model=None, llm_documents=None, llm_knowledge_jobs=None, llm_knowledge_llm_user_group=None, organization=None, resource_spec_preset=None, vectordb_connection=None, local_vars_configuration=None):  # noqa: E501
        """OrmLLMKnowledgeEdges - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration.get_default_copy()
        self.local_vars_configuration = local_vars_configuration

        self._cluster = None
        self._created_by = None
        self._embedding_model = None
        self._llm_documents = None
        self._llm_knowledge_jobs = None
        self._llm_knowledge_llm_user_group = None
        self._organization = None
        self._resource_spec_preset = None
        self._vectordb_connection = None
        self.discriminator = None

        if cluster is not None:
            self.cluster = cluster
        if created_by is not None:
            self.created_by = created_by
        if embedding_model is not None:
            self.embedding_model = embedding_model
        if llm_documents is not None:
            self.llm_documents = llm_documents
        if llm_knowledge_jobs is not None:
            self.llm_knowledge_jobs = llm_knowledge_jobs
        if llm_knowledge_llm_user_group is not None:
            self.llm_knowledge_llm_user_group = llm_knowledge_llm_user_group
        if organization is not None:
            self.organization = organization
        if resource_spec_preset is not None:
            self.resource_spec_preset = resource_spec_preset
        if vectordb_connection is not None:
            self.vectordb_connection = vectordb_connection

    @property
    def cluster(self):
        """Gets the cluster of this OrmLLMKnowledgeEdges.  # noqa: E501


        :return: The cluster of this OrmLLMKnowledgeEdges.  # noqa: E501
        :rtype: OrmKernelCluster
        """
        return self._cluster

    @cluster.setter
    def cluster(self, cluster):
        """Sets the cluster of this OrmLLMKnowledgeEdges.


        :param cluster: The cluster of this OrmLLMKnowledgeEdges.  # noqa: E501
        :type cluster: OrmKernelCluster
        """

        self._cluster = cluster

    @property
    def created_by(self):
        """Gets the created_by of this OrmLLMKnowledgeEdges.  # noqa: E501


        :return: The created_by of this OrmLLMKnowledgeEdges.  # noqa: E501
        :rtype: OrmUser
        """
        return self._created_by

    @created_by.setter
    def created_by(self, created_by):
        """Sets the created_by of this OrmLLMKnowledgeEdges.


        :param created_by: The created_by of this OrmLLMKnowledgeEdges.  # noqa: E501
        :type created_by: OrmUser
        """

        self._created_by = created_by

    @property
    def embedding_model(self):
        """Gets the embedding_model of this OrmLLMKnowledgeEdges.  # noqa: E501


        :return: The embedding_model of this OrmLLMKnowledgeEdges.  # noqa: E501
        :rtype: OrmLLMModelConnection
        """
        return self._embedding_model

    @embedding_model.setter
    def embedding_model(self, embedding_model):
        """Sets the embedding_model of this OrmLLMKnowledgeEdges.


        :param embedding_model: The embedding_model of this OrmLLMKnowledgeEdges.  # noqa: E501
        :type embedding_model: OrmLLMModelConnection
        """

        self._embedding_model = embedding_model

    @property
    def llm_documents(self):
        """Gets the llm_documents of this OrmLLMKnowledgeEdges.  # noqa: E501


        :return: The llm_documents of this OrmLLMKnowledgeEdges.  # noqa: E501
        :rtype: list[OrmLLMDocument]
        """
        return self._llm_documents

    @llm_documents.setter
    def llm_documents(self, llm_documents):
        """Sets the llm_documents of this OrmLLMKnowledgeEdges.


        :param llm_documents: The llm_documents of this OrmLLMKnowledgeEdges.  # noqa: E501
        :type llm_documents: list[OrmLLMDocument]
        """

        self._llm_documents = llm_documents

    @property
    def llm_knowledge_jobs(self):
        """Gets the llm_knowledge_jobs of this OrmLLMKnowledgeEdges.  # noqa: E501


        :return: The llm_knowledge_jobs of this OrmLLMKnowledgeEdges.  # noqa: E501
        :rtype: list[OrmLLMKnowledgeJob]
        """
        return self._llm_knowledge_jobs

    @llm_knowledge_jobs.setter
    def llm_knowledge_jobs(self, llm_knowledge_jobs):
        """Sets the llm_knowledge_jobs of this OrmLLMKnowledgeEdges.


        :param llm_knowledge_jobs: The llm_knowledge_jobs of this OrmLLMKnowledgeEdges.  # noqa: E501
        :type llm_knowledge_jobs: list[OrmLLMKnowledgeJob]
        """

        self._llm_knowledge_jobs = llm_knowledge_jobs

    @property
    def llm_knowledge_llm_user_group(self):
        """Gets the llm_knowledge_llm_user_group of this OrmLLMKnowledgeEdges.  # noqa: E501


        :return: The llm_knowledge_llm_user_group of this OrmLLMKnowledgeEdges.  # noqa: E501
        :rtype: list[OrmLLMKnowledgeLLMUserGroup]
        """
        return self._llm_knowledge_llm_user_group

    @llm_knowledge_llm_user_group.setter
    def llm_knowledge_llm_user_group(self, llm_knowledge_llm_user_group):
        """Sets the llm_knowledge_llm_user_group of this OrmLLMKnowledgeEdges.


        :param llm_knowledge_llm_user_group: The llm_knowledge_llm_user_group of this OrmLLMKnowledgeEdges.  # noqa: E501
        :type llm_knowledge_llm_user_group: list[OrmLLMKnowledgeLLMUserGroup]
        """

        self._llm_knowledge_llm_user_group = llm_knowledge_llm_user_group

    @property
    def organization(self):
        """Gets the organization of this OrmLLMKnowledgeEdges.  # noqa: E501


        :return: The organization of this OrmLLMKnowledgeEdges.  # noqa: E501
        :rtype: OrmOrganization
        """
        return self._organization

    @organization.setter
    def organization(self, organization):
        """Sets the organization of this OrmLLMKnowledgeEdges.


        :param organization: The organization of this OrmLLMKnowledgeEdges.  # noqa: E501
        :type organization: OrmOrganization
        """

        self._organization = organization

    @property
    def resource_spec_preset(self):
        """Gets the resource_spec_preset of this OrmLLMKnowledgeEdges.  # noqa: E501


        :return: The resource_spec_preset of this OrmLLMKnowledgeEdges.  # noqa: E501
        :rtype: OrmKernelResourceSpec
        """
        return self._resource_spec_preset

    @resource_spec_preset.setter
    def resource_spec_preset(self, resource_spec_preset):
        """Sets the resource_spec_preset of this OrmLLMKnowledgeEdges.


        :param resource_spec_preset: The resource_spec_preset of this OrmLLMKnowledgeEdges.  # noqa: E501
        :type resource_spec_preset: OrmKernelResourceSpec
        """

        self._resource_spec_preset = resource_spec_preset

    @property
    def vectordb_connection(self):
        """Gets the vectordb_connection of this OrmLLMKnowledgeEdges.  # noqa: E501


        :return: The vectordb_connection of this OrmLLMKnowledgeEdges.  # noqa: E501
        :rtype: OrmLLMVectorDBConnection
        """
        return self._vectordb_connection

    @vectordb_connection.setter
    def vectordb_connection(self, vectordb_connection):
        """Sets the vectordb_connection of this OrmLLMKnowledgeEdges.


        :param vectordb_connection: The vectordb_connection of this OrmLLMKnowledgeEdges.  # noqa: E501
        :type vectordb_connection: OrmLLMVectorDBConnection
        """

        self._vectordb_connection = vectordb_connection

    def to_dict(self, serialize=False):
        """Returns the model properties as a dict"""
        result = {}

        def convert(x):
            if hasattr(x, "to_dict"):
                args = getfullargspec(x.to_dict).args
                if len(args) == 1:
                    return x.to_dict()
                else:
                    return x.to_dict(serialize)
            else:
                return x

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            attr = self.attribute_map.get(attr, attr) if serialize else attr
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: convert(x),
                    value
                ))
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], convert(item[1])),
                    value.items()
                ))
            else:
                result[attr] = convert(value)

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, OrmLLMKnowledgeEdges):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, OrmLLMKnowledgeEdges):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Aron API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


try:
    from inspect import getfullargspec
except ImportError:
    from inspect import getargspec as getfullargspec
import pprint
import re  # noqa: F401
import six

from openapi_client.configuration import Configuration


class OrmWorkspacePort(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'credential_key': 'str',
        'credential_type': 'str',
        'credential_value': 'str',
        'expose_type': 'str',
        'health_check_path': 'str',
        'name': 'str',
        'port': 'int'
    }

    attribute_map = {
        'credential_key': 'credential_key',
        'credential_type': 'credential_type',
        'credential_value': 'credential_value',
        'expose_type': 'expose_type',
        'health_check_path': 'health_check_path',
        'name': 'name',
        'port': 'port'
    }

    def __init__(self, credential_key=None, credential_type=None, credential_value=None, expose_type='http', health_check_path=None, name=None, port=None, local_vars_configuration=None):  # noqa: E501
        """OrmWorkspacePort - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration.get_default_copy()
        self.local_vars_configuration = local_vars_configuration

        self._credential_key = None
        self._credential_type = None
        self._credential_value = None
        self._expose_type = None
        self._health_check_path = None
        self._name = None
        self._port = None
        self.discriminator = None

        if credential_key is not None:
            self.credential_key = credential_key
        if credential_type is not None:
            self.credential_type = credential_type
        if credential_value is not None:
            self.credential_value = credential_value
        if expose_type is not None:
            self.expose_type = expose_type
        if health_check_path is not None:
            self.health_check_path = health_check_path
        if name is not None:
            self.name = name
        if port is not None:
            self.port = port

    @property
    def credential_key(self):
        """Gets the credential_key of this OrmWorkspacePort.  # noqa: E501


        :return: The credential_key of this OrmWorkspacePort.  # noqa: E501
        :rtype: str
        """
        return self._credential_key

    @credential_key.setter
    def credential_key(self, credential_key):
        """Sets the credential_key of this OrmWorkspacePort.


        :param credential_key: The credential_key of this OrmWorkspacePort.  # noqa: E501
        :type credential_key: str
        """

        self._credential_key = credential_key

    @property
    def credential_type(self):
        """Gets the credential_type of this OrmWorkspacePort.  # noqa: E501


        :return: The credential_type of this OrmWorkspacePort.  # noqa: E501
        :rtype: str
        """
        return self._credential_type

    @credential_type.setter
    def credential_type(self, credential_type):
        """Sets the credential_type of this OrmWorkspacePort.


        :param credential_type: The credential_type of this OrmWorkspacePort.  # noqa: E501
        :type credential_type: str
        """

        self._credential_type = credential_type

    @property
    def credential_value(self):
        """Gets the credential_value of this OrmWorkspacePort.  # noqa: E501


        :return: The credential_value of this OrmWorkspacePort.  # noqa: E501
        :rtype: str
        """
        return self._credential_value

    @credential_value.setter
    def credential_value(self, credential_value):
        """Sets the credential_value of this OrmWorkspacePort.


        :param credential_value: The credential_value of this OrmWorkspacePort.  # noqa: E501
        :type credential_value: str
        """

        self._credential_value = credential_value

    @property
    def expose_type(self):
        """Gets the expose_type of this OrmWorkspacePort.  # noqa: E501


        :return: The expose_type of this OrmWorkspacePort.  # noqa: E501
        :rtype: str
        """
        return self._expose_type

    @expose_type.setter
    def expose_type(self, expose_type):
        """Sets the expose_type of this OrmWorkspacePort.


        :param expose_type: The expose_type of this OrmWorkspacePort.  # noqa: E501
        :type expose_type: str
        """
        allowed_values = ["tcp", "http"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and expose_type not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `expose_type` ({0}), must be one of {1}"  # noqa: E501
                .format(expose_type, allowed_values)
            )

        self._expose_type = expose_type

    @property
    def health_check_path(self):
        """Gets the health_check_path of this OrmWorkspacePort.  # noqa: E501


        :return: The health_check_path of this OrmWorkspacePort.  # noqa: E501
        :rtype: str
        """
        return self._health_check_path

    @health_check_path.setter
    def health_check_path(self, health_check_path):
        """Sets the health_check_path of this OrmWorkspacePort.


        :param health_check_path: The health_check_path of this OrmWorkspacePort.  # noqa: E501
        :type health_check_path: str
        """

        self._health_check_path = health_check_path

    @property
    def name(self):
        """Gets the name of this OrmWorkspacePort.  # noqa: E501


        :return: The name of this OrmWorkspacePort.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this OrmWorkspacePort.


        :param name: The name of this OrmWorkspacePort.  # noqa: E501
        :type name: str
        """

        self._name = name

    @property
    def port(self):
        """Gets the port of this OrmWorkspacePort.  # noqa: E501


        :return: The port of this OrmWorkspacePort.  # noqa: E501
        :rtype: int
        """
        return self._port

    @port.setter
    def port(self, port):
        """Sets the port of this OrmWorkspacePort.


        :param port: The port of this OrmWorkspacePort.  # noqa: E501
        :type port: int
        """

        self._port = port

    def to_dict(self, serialize=False):
        """Returns the model properties as a dict"""
        result = {}

        def convert(x):
            if hasattr(x, "to_dict"):
                args = getfullargspec(x.to_dict).args
                if len(args) == 1:
                    return x.to_dict()
                else:
                    return x.to_dict(serialize)
            else:
                return x

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            attr = self.attribute_map.get(attr, attr) if serialize else attr
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: convert(x),
                    value
                ))
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], convert(item[1])),
                    value.items()
                ))
            else:
                result[attr] = convert(value)

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, OrmWorkspacePort):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, OrmWorkspacePort):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Aron API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


try:
    from inspect import getfullargspec
except ImportError:
    from inspect import getargspec as getfullargspec
import pprint
import re  # noqa: F401
import six

from openapi_client.configuration import Configuration


class ProtoLLMWorkflowRevision(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'created_by': 'ProtoUser',
        'created_by_id': 'int',
        'created_dt': 'float',
        'id': 'int',
        'is_starred': 'bool',
        'message': 'str',
        'number': 'int',
        'spec': 'V1WorkflowRevisionSpec',
        'tags': 'list[ProtoTag]',
        'updated_dt': 'float',
        'workflow_id': 'int'
    }

    attribute_map = {
        'created_by': 'created_by',
        'created_by_id': 'created_by_id',
        'created_dt': 'created_dt',
        'id': 'id',
        'is_starred': 'is_starred',
        'message': 'message',
        'number': 'number',
        'spec': 'spec',
        'tags': 'tags',
        'updated_dt': 'updated_dt',
        'workflow_id': 'workflow_id'
    }

    def __init__(self, created_by=None, created_by_id=None, created_dt=None, id=None, is_starred=None, message=None, number=None, spec=None, tags=None, updated_dt=None, workflow_id=None, local_vars_configuration=None):  # noqa: E501
        """ProtoLLMWorkflowRevision - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration.get_default_copy()
        self.local_vars_configuration = local_vars_configuration

        self._created_by = None
        self._created_by_id = None
        self._created_dt = None
        self._id = None
        self._is_starred = None
        self._message = None
        self._number = None
        self._spec = None
        self._tags = None
        self._updated_dt = None
        self._workflow_id = None
        self.discriminator = None

        if created_by is not None:
            self.created_by = created_by
        self.created_by_id = created_by_id
        self.created_dt = created_dt
        self.id = id
        if is_starred is not None:
            self.is_starred = is_starred
        if message is not None:
            self.message = message
        self.number = number
        self.spec = spec
        if tags is not None:
            self.tags = tags
        self.updated_dt = updated_dt
        self.workflow_id = workflow_id

    @property
    def created_by(self):
        """Gets the created_by of this ProtoLLMWorkflowRevision.  # noqa: E501


        :return: The created_by of this ProtoLLMWorkflowRevision.  # noqa: E501
        :rtype: ProtoUser
        """
        return self._created_by

    @created_by.setter
    def created_by(self, created_by):
        """Sets the created_by of this ProtoLLMWorkflowRevision.


        :param created_by: The created_by of this ProtoLLMWorkflowRevision.  # noqa: E501
        :type created_by: ProtoUser
        """

        self._created_by = created_by

    @property
    def created_by_id(self):
        """Gets the created_by_id of this ProtoLLMWorkflowRevision.  # noqa: E501


        :return: The created_by_id of this ProtoLLMWorkflowRevision.  # noqa: E501
        :rtype: int
        """
        return self._created_by_id

    @created_by_id.setter
    def created_by_id(self, created_by_id):
        """Sets the created_by_id of this ProtoLLMWorkflowRevision.


        :param created_by_id: The created_by_id of this ProtoLLMWorkflowRevision.  # noqa: E501
        :type created_by_id: int
        """
        if self.local_vars_configuration.client_side_validation and created_by_id is None:  # noqa: E501
            raise ValueError("Invalid value for `created_by_id`, must not be `None`")  # noqa: E501

        self._created_by_id = created_by_id

    @property
    def created_dt(self):
        """Gets the created_dt of this ProtoLLMWorkflowRevision.  # noqa: E501


        :return: The created_dt of this ProtoLLMWorkflowRevision.  # noqa: E501
        :rtype: float
        """
        return self._created_dt

    @created_dt.setter
    def created_dt(self, created_dt):
        """Sets the created_dt of this ProtoLLMWorkflowRevision.


        :param created_dt: The created_dt of this ProtoLLMWorkflowRevision.  # noqa: E501
        :type created_dt: float
        """
        if self.local_vars_configuration.client_side_validation and created_dt is None:  # noqa: E501
            raise ValueError("Invalid value for `created_dt`, must not be `None`")  # noqa: E501

        self._created_dt = created_dt

    @property
    def id(self):
        """Gets the id of this ProtoLLMWorkflowRevision.  # noqa: E501


        :return: The id of this ProtoLLMWorkflowRevision.  # noqa: E501
        :rtype: int
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this ProtoLLMWorkflowRevision.


        :param id: The id of this ProtoLLMWorkflowRevision.  # noqa: E501
        :type id: int
        """
        if self.local_vars_configuration.client_side_validation and id is None:  # noqa: E501
            raise ValueError("Invalid value for `id`, must not be `None`")  # noqa: E501

        self._id = id

    @property
    def is_starred(self):
        """Gets the is_starred of this ProtoLLMWorkflowRevision.  # noqa: E501


        :return: The is_starred of this ProtoLLMWorkflowRevision.  # noqa: E501
        :rtype: bool
        """
        return self._is_starred

    @is_starred.setter
    def is_starred(self, is_starred):
        """Sets the is_starred of this ProtoLLMWorkflowRevision.


        :param is_starred: The is_starred of this ProtoLLMWorkflowRevision.  # noqa: E501
        :type is_starred: bool
        """

        self._is_starred = is_starred

    @property
    def message(self):
        """Gets the message of this ProtoLLMWorkflowRevision.  # noqa: E501


        :return: The message of this ProtoLLMWorkflowRevision.  # noqa: E501
        :rtype: str
        """
        return self._message

    @message.setter
    def message(self, message):
        """Sets the message of this ProtoLLMWorkflowRevision.


        :param message: The message of this ProtoLLMWorkflowRevision.  # noqa: E501
        :type message: str
        """

        self._message = message

    @property
    def number(self):
        """Gets the number of this ProtoLLMWorkflowRevision.  # noqa: E501


        :return: The number of this ProtoLLMWorkflowRevision.  # noqa: E501
        :rtype: int
        """
        return self._number

    @number.setter
    def number(self, number):
        """Sets the number of this ProtoLLMWorkflowRevision.


        :param number: The number of this ProtoLLMWorkflowRevision.  # noqa: E501
        :type number: int
        """
        if self.local_vars_configuration.client_side_validation and number is None:  # noqa: E501
            raise ValueError("Invalid value for `number`, must not be `None`")  # noqa: E501

        self._number = number

    @property
    def spec(self):
        """Gets the spec of this ProtoLLMWorkflowRevision.  # noqa: E501


        :return: The spec of this ProtoLLMWorkflowRevision.  # noqa: E501
        :rtype: V1WorkflowRevisionSpec
        """
        return self._spec

    @spec.setter
    def spec(self, spec):
        """Sets the spec of this ProtoLLMWorkflowRevision.


        :param spec: The spec of this ProtoLLMWorkflowRevision.  # noqa: E501
        :type spec: V1WorkflowRevisionSpec
        """
        if self.local_vars_configuration.client_side_validation and spec is None:  # noqa: E501
            raise ValueError("Invalid value for `spec`, must not be `None`")  # noqa: E501

        self._spec = spec

    @property
    def tags(self):
        """Gets the tags of this ProtoLLMWorkflowRevision.  # noqa: E501


        :return: The tags of this ProtoLLMWorkflowRevision.  # noqa: E501
        :rtype: list[ProtoTag]
        """
        return self._tags

    @tags.setter
    def tags(self, tags):
        """Sets the tags of this ProtoLLMWorkflowRevision.


        :param tags: The tags of this ProtoLLMWorkflowRevision.  # noqa: E501
        :type tags: list[ProtoTag]
        """

        self._tags = tags

    @property
    def updated_dt(self):
        """Gets the updated_dt of this ProtoLLMWorkflowRevision.  # noqa: E501


        :return: The updated_dt of this ProtoLLMWorkflowRevision.  # noqa: E501
        :rtype: float
        """
        return self._updated_dt

    @updated_dt.setter
    def updated_dt(self, updated_dt):
        """Sets the updated_dt of this ProtoLLMWorkflowRevision.


        :param updated_dt: The updated_dt of this ProtoLLMWorkflowRevision.  # noqa: E501
        :type updated_dt: float
        """
        if self.local_vars_configuration.client_side_validation and updated_dt is None:  # noqa: E501
            raise ValueError("Invalid value for `updated_dt`, must not be `None`")  # noqa: E501

        self._updated_dt = updated_dt

    @property
    def workflow_id(self):
        """Gets the workflow_id of this ProtoLLMWorkflowRevision.  # noqa: E501


        :return: The workflow_id of this ProtoLLMWorkflowRevision.  # noqa: E501
        :rtype: int
        """
        return self._workflow_id

    @workflow_id.setter
    def workflow_id(self, workflow_id):
        """Sets the workflow_id of this ProtoLLMWorkflowRevision.


        :param workflow_id: The workflow_id of this ProtoLLMWorkflowRevision.  # noqa: E501
        :type workflow_id: int
        """
        if self.local_vars_configuration.client_side_validation and workflow_id is None:  # noqa: E501
            raise ValueError("Invalid value for `workflow_id`, must not be `None`")  # noqa: E501

        self._workflow_id = workflow_id

    def to_dict(self, serialize=False):
        """Returns the model properties as a dict"""
        result = {}

        def convert(x):
            if hasattr(x, "to_dict"):
                args = getfullargspec(x.to_dict).args
                if len(args) == 1:
                    return x.to_dict()
                else:
                    return x.to_dict(serialize)
            else:
                return x

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            attr = self.attribute_map.get(attr, attr) if serialize else attr
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: convert(x),
                    value
                ))
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], convert(item[1])),
                    value.items()
                ))
            else:
                result[attr] = convert(value)

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ProtoLLMWorkflowRevision):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, ProtoLLMWorkflowRevision):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Aron API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


try:
    from inspect import getfullargspec
except ImportError:
    from inspect import getargspec as getfullargspec
import pprint
import re  # noqa: F401
import six

from openapi_client.configuration import Configuration


class OrmClusterCustomEndpointConfig(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'certificate_secret_name': 'str',
        'cluster_agent_namespace': 'str',
        'nodeport_config': 'OrmNodePortConfig',
        'subdomain_config': 'OrmSubdomainConfig',
        'tls_enabled': 'bool',
        'type': 'str'
    }

    attribute_map = {
        'certificate_secret_name': 'certificate_secret_name',
        'cluster_agent_namespace': 'cluster_agent_namespace',
        'nodeport_config': 'nodeport_config',
        'subdomain_config': 'subdomain_config',
        'tls_enabled': 'tls_enabled',
        'type': 'type'
    }

    def __init__(self, certificate_secret_name=None, cluster_agent_namespace=None, nodeport_config=None, subdomain_config=None, tls_enabled=None, type=None, local_vars_configuration=None):  # noqa: E501
        """OrmClusterCustomEndpointConfig - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration.get_default_copy()
        self.local_vars_configuration = local_vars_configuration

        self._certificate_secret_name = None
        self._cluster_agent_namespace = None
        self._nodeport_config = None
        self._subdomain_config = None
        self._tls_enabled = None
        self._type = None
        self.discriminator = None

        self.certificate_secret_name = certificate_secret_name
        if cluster_agent_namespace is not None:
            self.cluster_agent_namespace = cluster_agent_namespace
        if nodeport_config is not None:
            self.nodeport_config = nodeport_config
        if subdomain_config is not None:
            self.subdomain_config = subdomain_config
        if tls_enabled is not None:
            self.tls_enabled = tls_enabled
        if type is not None:
            self.type = type

    @property
    def certificate_secret_name(self):
        """Gets the certificate_secret_name of this OrmClusterCustomEndpointConfig.  # noqa: E501


        :return: The certificate_secret_name of this OrmClusterCustomEndpointConfig.  # noqa: E501
        :rtype: str
        """
        return self._certificate_secret_name

    @certificate_secret_name.setter
    def certificate_secret_name(self, certificate_secret_name):
        """Sets the certificate_secret_name of this OrmClusterCustomEndpointConfig.


        :param certificate_secret_name: The certificate_secret_name of this OrmClusterCustomEndpointConfig.  # noqa: E501
        :type certificate_secret_name: str
        """

        self._certificate_secret_name = certificate_secret_name

    @property
    def cluster_agent_namespace(self):
        """Gets the cluster_agent_namespace of this OrmClusterCustomEndpointConfig.  # noqa: E501


        :return: The cluster_agent_namespace of this OrmClusterCustomEndpointConfig.  # noqa: E501
        :rtype: str
        """
        return self._cluster_agent_namespace

    @cluster_agent_namespace.setter
    def cluster_agent_namespace(self, cluster_agent_namespace):
        """Sets the cluster_agent_namespace of this OrmClusterCustomEndpointConfig.


        :param cluster_agent_namespace: The cluster_agent_namespace of this OrmClusterCustomEndpointConfig.  # noqa: E501
        :type cluster_agent_namespace: str
        """

        self._cluster_agent_namespace = cluster_agent_namespace

    @property
    def nodeport_config(self):
        """Gets the nodeport_config of this OrmClusterCustomEndpointConfig.  # noqa: E501


        :return: The nodeport_config of this OrmClusterCustomEndpointConfig.  # noqa: E501
        :rtype: OrmNodePortConfig
        """
        return self._nodeport_config

    @nodeport_config.setter
    def nodeport_config(self, nodeport_config):
        """Sets the nodeport_config of this OrmClusterCustomEndpointConfig.


        :param nodeport_config: The nodeport_config of this OrmClusterCustomEndpointConfig.  # noqa: E501
        :type nodeport_config: OrmNodePortConfig
        """

        self._nodeport_config = nodeport_config

    @property
    def subdomain_config(self):
        """Gets the subdomain_config of this OrmClusterCustomEndpointConfig.  # noqa: E501


        :return: The subdomain_config of this OrmClusterCustomEndpointConfig.  # noqa: E501
        :rtype: OrmSubdomainConfig
        """
        return self._subdomain_config

    @subdomain_config.setter
    def subdomain_config(self, subdomain_config):
        """Sets the subdomain_config of this OrmClusterCustomEndpointConfig.


        :param subdomain_config: The subdomain_config of this OrmClusterCustomEndpointConfig.  # noqa: E501
        :type subdomain_config: OrmSubdomainConfig
        """

        self._subdomain_config = subdomain_config

    @property
    def tls_enabled(self):
        """Gets the tls_enabled of this OrmClusterCustomEndpointConfig.  # noqa: E501


        :return: The tls_enabled of this OrmClusterCustomEndpointConfig.  # noqa: E501
        :rtype: bool
        """
        return self._tls_enabled

    @tls_enabled.setter
    def tls_enabled(self, tls_enabled):
        """Sets the tls_enabled of this OrmClusterCustomEndpointConfig.


        :param tls_enabled: The tls_enabled of this OrmClusterCustomEndpointConfig.  # noqa: E501
        :type tls_enabled: bool
        """

        self._tls_enabled = tls_enabled

    @property
    def type(self):
        """Gets the type of this OrmClusterCustomEndpointConfig.  # noqa: E501


        :return: The type of this OrmClusterCustomEndpointConfig.  # noqa: E501
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this OrmClusterCustomEndpointConfig.


        :param type: The type of this OrmClusterCustomEndpointConfig.  # noqa: E501
        :type type: str
        """

        self._type = type

    def to_dict(self, serialize=False):
        """Returns the model properties as a dict"""
        result = {}

        def convert(x):
            if hasattr(x, "to_dict"):
                args = getfullargspec(x.to_dict).args
                if len(args) == 1:
                    return x.to_dict()
                else:
                    return x.to_dict(serialize)
            else:
                return x

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            attr = self.attribute_map.get(attr, attr) if serialize else attr
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: convert(x),
                    value
                ))
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], convert(item[1])),
                    value.items()
                ))
            else:
                result[attr] = convert(value)

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, OrmClusterCustomEndpointConfig):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, OrmClusterCustomEndpointConfig):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Aron API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


try:
    from inspect import getfullargspec
except ImportError:
    from inspect import getargspec as getfullargspec
import pprint
import re  # noqa: F401
import six

from openapi_client.configuration import Configuration


class OrmOrganizationKernelCluster(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'allowed_node_ids': 'list[int]',
        'allowed_resource_spec_names': 'list[str]',
        'created_dt': 'datetime',
        'edges': 'OrmOrganizationKernelClusterEdges',
        'id': 'int',
        'immutable_slug': 'str',
        'initialized_dt': 'datetime',
        'is_resource_spec_restricted': 'bool',
        'kernel_cluster_id': 'int',
        'organization_id': 'int',
        'updated_dt': 'datetime'
    }

    attribute_map = {
        'allowed_node_ids': 'allowed_node_ids',
        'allowed_resource_spec_names': 'allowed_resource_spec_names',
        'created_dt': 'created_dt',
        'edges': 'edges',
        'id': 'id',
        'immutable_slug': 'immutable_slug',
        'initialized_dt': 'initialized_dt',
        'is_resource_spec_restricted': 'is_resource_spec_restricted',
        'kernel_cluster_id': 'kernel_cluster_id',
        'organization_id': 'organization_id',
        'updated_dt': 'updated_dt'
    }

    def __init__(self, allowed_node_ids=None, allowed_resource_spec_names=None, created_dt=None, edges=None, id=None, immutable_slug=None, initialized_dt=None, is_resource_spec_restricted=None, kernel_cluster_id=None, organization_id=None, updated_dt=None, local_vars_configuration=None):  # noqa: E501
        """OrmOrganizationKernelCluster - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration.get_default_copy()
        self.local_vars_configuration = local_vars_configuration

        self._allowed_node_ids = None
        self._allowed_resource_spec_names = None
        self._created_dt = None
        self._edges = None
        self._id = None
        self._immutable_slug = None
        self._initialized_dt = None
        self._is_resource_spec_restricted = None
        self._kernel_cluster_id = None
        self._organization_id = None
        self._updated_dt = None
        self.discriminator = None

        if allowed_node_ids is not None:
            self.allowed_node_ids = allowed_node_ids
        if allowed_resource_spec_names is not None:
            self.allowed_resource_spec_names = allowed_resource_spec_names
        if created_dt is not None:
            self.created_dt = created_dt
        if edges is not None:
            self.edges = edges
        if id is not None:
            self.id = id
        if immutable_slug is not None:
            self.immutable_slug = immutable_slug
        self.initialized_dt = initialized_dt
        if is_resource_spec_restricted is not None:
            self.is_resource_spec_restricted = is_resource_spec_restricted
        if kernel_cluster_id is not None:
            self.kernel_cluster_id = kernel_cluster_id
        if organization_id is not None:
            self.organization_id = organization_id
        if updated_dt is not None:
            self.updated_dt = updated_dt

    @property
    def allowed_node_ids(self):
        """Gets the allowed_node_ids of this OrmOrganizationKernelCluster.  # noqa: E501


        :return: The allowed_node_ids of this OrmOrganizationKernelCluster.  # noqa: E501
        :rtype: list[int]
        """
        return self._allowed_node_ids

    @allowed_node_ids.setter
    def allowed_node_ids(self, allowed_node_ids):
        """Sets the allowed_node_ids of this OrmOrganizationKernelCluster.


        :param allowed_node_ids: The allowed_node_ids of this OrmOrganizationKernelCluster.  # noqa: E501
        :type allowed_node_ids: list[int]
        """

        self._allowed_node_ids = allowed_node_ids

    @property
    def allowed_resource_spec_names(self):
        """Gets the allowed_resource_spec_names of this OrmOrganizationKernelCluster.  # noqa: E501


        :return: The allowed_resource_spec_names of this OrmOrganizationKernelCluster.  # noqa: E501
        :rtype: list[str]
        """
        return self._allowed_resource_spec_names

    @allowed_resource_spec_names.setter
    def allowed_resource_spec_names(self, allowed_resource_spec_names):
        """Sets the allowed_resource_spec_names of this OrmOrganizationKernelCluster.


        :param allowed_resource_spec_names: The allowed_resource_spec_names of this OrmOrganizationKernelCluster.  # noqa: E501
        :type allowed_resource_spec_names: list[str]
        """

        self._allowed_resource_spec_names = allowed_resource_spec_names

    @property
    def created_dt(self):
        """Gets the created_dt of this OrmOrganizationKernelCluster.  # noqa: E501


        :return: The created_dt of this OrmOrganizationKernelCluster.  # noqa: E501
        :rtype: datetime
        """
        return self._created_dt

    @created_dt.setter
    def created_dt(self, created_dt):
        """Sets the created_dt of this OrmOrganizationKernelCluster.


        :param created_dt: The created_dt of this OrmOrganizationKernelCluster.  # noqa: E501
        :type created_dt: datetime
        """

        self._created_dt = created_dt

    @property
    def edges(self):
        """Gets the edges of this OrmOrganizationKernelCluster.  # noqa: E501


        :return: The edges of this OrmOrganizationKernelCluster.  # noqa: E501
        :rtype: OrmOrganizationKernelClusterEdges
        """
        return self._edges

    @edges.setter
    def edges(self, edges):
        """Sets the edges of this OrmOrganizationKernelCluster.


        :param edges: The edges of this OrmOrganizationKernelCluster.  # noqa: E501
        :type edges: OrmOrganizationKernelClusterEdges
        """

        self._edges = edges

    @property
    def id(self):
        """Gets the id of this OrmOrganizationKernelCluster.  # noqa: E501


        :return: The id of this OrmOrganizationKernelCluster.  # noqa: E501
        :rtype: int
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this OrmOrganizationKernelCluster.


        :param id: The id of this OrmOrganizationKernelCluster.  # noqa: E501
        :type id: int
        """

        self._id = id

    @property
    def immutable_slug(self):
        """Gets the immutable_slug of this OrmOrganizationKernelCluster.  # noqa: E501


        :return: The immutable_slug of this OrmOrganizationKernelCluster.  # noqa: E501
        :rtype: str
        """
        return self._immutable_slug

    @immutable_slug.setter
    def immutable_slug(self, immutable_slug):
        """Sets the immutable_slug of this OrmOrganizationKernelCluster.


        :param immutable_slug: The immutable_slug of this OrmOrganizationKernelCluster.  # noqa: E501
        :type immutable_slug: str
        """

        self._immutable_slug = immutable_slug

    @property
    def initialized_dt(self):
        """Gets the initialized_dt of this OrmOrganizationKernelCluster.  # noqa: E501


        :return: The initialized_dt of this OrmOrganizationKernelCluster.  # noqa: E501
        :rtype: datetime
        """
        return self._initialized_dt

    @initialized_dt.setter
    def initialized_dt(self, initialized_dt):
        """Sets the initialized_dt of this OrmOrganizationKernelCluster.


        :param initialized_dt: The initialized_dt of this OrmOrganizationKernelCluster.  # noqa: E501
        :type initialized_dt: datetime
        """

        self._initialized_dt = initialized_dt

    @property
    def is_resource_spec_restricted(self):
        """Gets the is_resource_spec_restricted of this OrmOrganizationKernelCluster.  # noqa: E501


        :return: The is_resource_spec_restricted of this OrmOrganizationKernelCluster.  # noqa: E501
        :rtype: bool
        """
        return self._is_resource_spec_restricted

    @is_resource_spec_restricted.setter
    def is_resource_spec_restricted(self, is_resource_spec_restricted):
        """Sets the is_resource_spec_restricted of this OrmOrganizationKernelCluster.


        :param is_resource_spec_restricted: The is_resource_spec_restricted of this OrmOrganizationKernelCluster.  # noqa: E501
        :type is_resource_spec_restricted: bool
        """

        self._is_resource_spec_restricted = is_resource_spec_restricted

    @property
    def kernel_cluster_id(self):
        """Gets the kernel_cluster_id of this OrmOrganizationKernelCluster.  # noqa: E501


        :return: The kernel_cluster_id of this OrmOrganizationKernelCluster.  # noqa: E501
        :rtype: int
        """
        return self._kernel_cluster_id

    @kernel_cluster_id.setter
    def kernel_cluster_id(self, kernel_cluster_id):
        """Sets the kernel_cluster_id of this OrmOrganizationKernelCluster.


        :param kernel_cluster_id: The kernel_cluster_id of this OrmOrganizationKernelCluster.  # noqa: E501
        :type kernel_cluster_id: int
        """

        self._kernel_cluster_id = kernel_cluster_id

    @property
    def organization_id(self):
        """Gets the organization_id of this OrmOrganizationKernelCluster.  # noqa: E501


        :return: The organization_id of this OrmOrganizationKernelCluster.  # noqa: E501
        :rtype: int
        """
        return self._organization_id

    @organization_id.setter
    def organization_id(self, organization_id):
        """Sets the organization_id of this OrmOrganizationKernelCluster.


        :param organization_id: The organization_id of this OrmOrganizationKernelCluster.  # noqa: E501
        :type organization_id: int
        """

        self._organization_id = organization_id

    @property
    def updated_dt(self):
        """Gets the updated_dt of this OrmOrganizationKernelCluster.  # noqa: E501


        :return: The updated_dt of this OrmOrganizationKernelCluster.  # noqa: E501
        :rtype: datetime
        """
        return self._updated_dt

    @updated_dt.setter
    def updated_dt(self, updated_dt):
        """Sets the updated_dt of this OrmOrganizationKernelCluster.


        :param updated_dt: The updated_dt of this OrmOrganizationKernelCluster.  # noqa: E501
        :type updated_dt: datetime
        """

        self._updated_dt = updated_dt

    def to_dict(self, serialize=False):
        """Returns the model properties as a dict"""
        result = {}

        def convert(x):
            if hasattr(x, "to_dict"):
                args = getfullargspec(x.to_dict).args
                if len(args) == 1:
                    return x.to_dict()
                else:
                    return x.to_dict(serialize)
            else:
                return x

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            attr = self.attribute_map.get(attr, attr) if serialize else attr
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: convert(x),
                    value
                ))
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], convert(item[1])),
                    value.items()
                ))
            else:
                result[attr] = convert(value)

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, OrmOrganizationKernelCluster):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, OrmOrganizationKernelCluster):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Aron API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


try:
    from inspect import getfullargspec
except ImportError:
    from inspect import getargspec as getfullargspec
import pprint
import re  # noqa: F401
import six

from openapi_client.configuration import Configuration


class OrmProjectDashboardExperimentFieldConfig(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'created_dt': 'datetime',
        'dashboard_id': 'int',
        'display_name': 'str',
        'edges': 'OrmProjectDashboardExperimentFieldConfigEdges',
        'experiment_field_id': 'int',
        'id': 'int',
        'is_filterable': 'bool',
        'is_hidden': 'bool',
        'is_pinned': 'bool',
        'is_sortable': 'bool',
        'order': 'int',
        'updated_dt': 'datetime',
        'width': 'int'
    }

    attribute_map = {
        'created_dt': 'created_dt',
        'dashboard_id': 'dashboard_id',
        'display_name': 'display_name',
        'edges': 'edges',
        'experiment_field_id': 'experiment_field_id',
        'id': 'id',
        'is_filterable': 'is_filterable',
        'is_hidden': 'is_hidden',
        'is_pinned': 'is_pinned',
        'is_sortable': 'is_sortable',
        'order': 'order',
        'updated_dt': 'updated_dt',
        'width': 'width'
    }

    def __init__(self, created_dt=None, dashboard_id=None, display_name=None, edges=None, experiment_field_id=None, id=None, is_filterable=None, is_hidden=None, is_pinned=None, is_sortable=None, order=None, updated_dt=None, width=None, local_vars_configuration=None):  # noqa: E501
        """OrmProjectDashboardExperimentFieldConfig - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration.get_default_copy()
        self.local_vars_configuration = local_vars_configuration

        self._created_dt = None
        self._dashboard_id = None
        self._display_name = None
        self._edges = None
        self._experiment_field_id = None
        self._id = None
        self._is_filterable = None
        self._is_hidden = None
        self._is_pinned = None
        self._is_sortable = None
        self._order = None
        self._updated_dt = None
        self._width = None
        self.discriminator = None

        if created_dt is not None:
            self.created_dt = created_dt
        if dashboard_id is not None:
            self.dashboard_id = dashboard_id
        if display_name is not None:
            self.display_name = display_name
        if edges is not None:
            self.edges = edges
        if experiment_field_id is not None:
            self.experiment_field_id = experiment_field_id
        if id is not None:
            self.id = id
        if is_filterable is not None:
            self.is_filterable = is_filterable
        if is_hidden is not None:
            self.is_hidden = is_hidden
        if is_pinned is not None:
            self.is_pinned = is_pinned
        if is_sortable is not None:
            self.is_sortable = is_sortable
        self.order = order
        if updated_dt is not None:
            self.updated_dt = updated_dt
        self.width = width

    @property
    def created_dt(self):
        """Gets the created_dt of this OrmProjectDashboardExperimentFieldConfig.  # noqa: E501


        :return: The created_dt of this OrmProjectDashboardExperimentFieldConfig.  # noqa: E501
        :rtype: datetime
        """
        return self._created_dt

    @created_dt.setter
    def created_dt(self, created_dt):
        """Sets the created_dt of this OrmProjectDashboardExperimentFieldConfig.


        :param created_dt: The created_dt of this OrmProjectDashboardExperimentFieldConfig.  # noqa: E501
        :type created_dt: datetime
        """

        self._created_dt = created_dt

    @property
    def dashboard_id(self):
        """Gets the dashboard_id of this OrmProjectDashboardExperimentFieldConfig.  # noqa: E501


        :return: The dashboard_id of this OrmProjectDashboardExperimentFieldConfig.  # noqa: E501
        :rtype: int
        """
        return self._dashboard_id

    @dashboard_id.setter
    def dashboard_id(self, dashboard_id):
        """Sets the dashboard_id of this OrmProjectDashboardExperimentFieldConfig.


        :param dashboard_id: The dashboard_id of this OrmProjectDashboardExperimentFieldConfig.  # noqa: E501
        :type dashboard_id: int
        """

        self._dashboard_id = dashboard_id

    @property
    def display_name(self):
        """Gets the display_name of this OrmProjectDashboardExperimentFieldConfig.  # noqa: E501


        :return: The display_name of this OrmProjectDashboardExperimentFieldConfig.  # noqa: E501
        :rtype: str
        """
        return self._display_name

    @display_name.setter
    def display_name(self, display_name):
        """Sets the display_name of this OrmProjectDashboardExperimentFieldConfig.


        :param display_name: The display_name of this OrmProjectDashboardExperimentFieldConfig.  # noqa: E501
        :type display_name: str
        """

        self._display_name = display_name

    @property
    def edges(self):
        """Gets the edges of this OrmProjectDashboardExperimentFieldConfig.  # noqa: E501


        :return: The edges of this OrmProjectDashboardExperimentFieldConfig.  # noqa: E501
        :rtype: OrmProjectDashboardExperimentFieldConfigEdges
        """
        return self._edges

    @edges.setter
    def edges(self, edges):
        """Sets the edges of this OrmProjectDashboardExperimentFieldConfig.


        :param edges: The edges of this OrmProjectDashboardExperimentFieldConfig.  # noqa: E501
        :type edges: OrmProjectDashboardExperimentFieldConfigEdges
        """

        self._edges = edges

    @property
    def experiment_field_id(self):
        """Gets the experiment_field_id of this OrmProjectDashboardExperimentFieldConfig.  # noqa: E501


        :return: The experiment_field_id of this OrmProjectDashboardExperimentFieldConfig.  # noqa: E501
        :rtype: int
        """
        return self._experiment_field_id

    @experiment_field_id.setter
    def experiment_field_id(self, experiment_field_id):
        """Sets the experiment_field_id of this OrmProjectDashboardExperimentFieldConfig.


        :param experiment_field_id: The experiment_field_id of this OrmProjectDashboardExperimentFieldConfig.  # noqa: E501
        :type experiment_field_id: int
        """

        self._experiment_field_id = experiment_field_id

    @property
    def id(self):
        """Gets the id of this OrmProjectDashboardExperimentFieldConfig.  # noqa: E501


        :return: The id of this OrmProjectDashboardExperimentFieldConfig.  # noqa: E501
        :rtype: int
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this OrmProjectDashboardExperimentFieldConfig.


        :param id: The id of this OrmProjectDashboardExperimentFieldConfig.  # noqa: E501
        :type id: int
        """

        self._id = id

    @property
    def is_filterable(self):
        """Gets the is_filterable of this OrmProjectDashboardExperimentFieldConfig.  # noqa: E501


        :return: The is_filterable of this OrmProjectDashboardExperimentFieldConfig.  # noqa: E501
        :rtype: bool
        """
        return self._is_filterable

    @is_filterable.setter
    def is_filterable(self, is_filterable):
        """Sets the is_filterable of this OrmProjectDashboardExperimentFieldConfig.


        :param is_filterable: The is_filterable of this OrmProjectDashboardExperimentFieldConfig.  # noqa: E501
        :type is_filterable: bool
        """

        self._is_filterable = is_filterable

    @property
    def is_hidden(self):
        """Gets the is_hidden of this OrmProjectDashboardExperimentFieldConfig.  # noqa: E501


        :return: The is_hidden of this OrmProjectDashboardExperimentFieldConfig.  # noqa: E501
        :rtype: bool
        """
        return self._is_hidden

    @is_hidden.setter
    def is_hidden(self, is_hidden):
        """Sets the is_hidden of this OrmProjectDashboardExperimentFieldConfig.


        :param is_hidden: The is_hidden of this OrmProjectDashboardExperimentFieldConfig.  # noqa: E501
        :type is_hidden: bool
        """

        self._is_hidden = is_hidden

    @property
    def is_pinned(self):
        """Gets the is_pinned of this OrmProjectDashboardExperimentFieldConfig.  # noqa: E501


        :return: The is_pinned of this OrmProjectDashboardExperimentFieldConfig.  # noqa: E501
        :rtype: bool
        """
        return self._is_pinned

    @is_pinned.setter
    def is_pinned(self, is_pinned):
        """Sets the is_pinned of this OrmProjectDashboardExperimentFieldConfig.


        :param is_pinned: The is_pinned of this OrmProjectDashboardExperimentFieldConfig.  # noqa: E501
        :type is_pinned: bool
        """

        self._is_pinned = is_pinned

    @property
    def is_sortable(self):
        """Gets the is_sortable of this OrmProjectDashboardExperimentFieldConfig.  # noqa: E501


        :return: The is_sortable of this OrmProjectDashboardExperimentFieldConfig.  # noqa: E501
        :rtype: bool
        """
        return self._is_sortable

    @is_sortable.setter
    def is_sortable(self, is_sortable):
        """Sets the is_sortable of this OrmProjectDashboardExperimentFieldConfig.


        :param is_sortable: The is_sortable of this OrmProjectDashboardExperimentFieldConfig.  # noqa: E501
        :type is_sortable: bool
        """

        self._is_sortable = is_sortable

    @property
    def order(self):
        """Gets the order of this OrmProjectDashboardExperimentFieldConfig.  # noqa: E501


        :return: The order of this OrmProjectDashboardExperimentFieldConfig.  # noqa: E501
        :rtype: int
        """
        return self._order

    @order.setter
    def order(self, order):
        """Sets the order of this OrmProjectDashboardExperimentFieldConfig.


        :param order: The order of this OrmProjectDashboardExperimentFieldConfig.  # noqa: E501
        :type order: int
        """

        self._order = order

    @property
    def updated_dt(self):
        """Gets the updated_dt of this OrmProjectDashboardExperimentFieldConfig.  # noqa: E501


        :return: The updated_dt of this OrmProjectDashboardExperimentFieldConfig.  # noqa: E501
        :rtype: datetime
        """
        return self._updated_dt

    @updated_dt.setter
    def updated_dt(self, updated_dt):
        """Sets the updated_dt of this OrmProjectDashboardExperimentFieldConfig.


        :param updated_dt: The updated_dt of this OrmProjectDashboardExperimentFieldConfig.  # noqa: E501
        :type updated_dt: datetime
        """

        self._updated_dt = updated_dt

    @property
    def width(self):
        """Gets the width of this OrmProjectDashboardExperimentFieldConfig.  # noqa: E501


        :return: The width of this OrmProjectDashboardExperimentFieldConfig.  # noqa: E501
        :rtype: int
        """
        return self._width

    @width.setter
    def width(self, width):
        """Sets the width of this OrmProjectDashboardExperimentFieldConfig.


        :param width: The width of this OrmProjectDashboardExperimentFieldConfig.  # noqa: E501
        :type width: int
        """

        self._width = width

    def to_dict(self, serialize=False):
        """Returns the model properties as a dict"""
        result = {}

        def convert(x):
            if hasattr(x, "to_dict"):
                args = getfullargspec(x.to_dict).args
                if len(args) == 1:
                    return x.to_dict()
                else:
                    return x.to_dict(serialize)
            else:
                return x

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            attr = self.attribute_map.get(attr, attr) if serialize else attr
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: convert(x),
                    value
                ))
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], convert(item[1])),
                    value.items()
                ))
            else:
                result[attr] = convert(value)

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, OrmProjectDashboardExperimentFieldConfig):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, OrmProjectDashboardExperimentFieldConfig):
            return True

        return self.to_dict() != other.to_dict()
